<?php

/* Inclusion des dépendances de cette classe */
require_once('Router.php');
require_once('model/Animal.php');

/**
 * Gère l'affichage HTML des pages.
 * Une vue est comme un squelette, c'est-à-dire une page HTML à trous,
 * dont il faut remplir les variables avant de l'afficher ;
 * mais les variables sont remplies via des méthodes make???Page().
 */
class View {

	/** Le routeur utilisé par cette vue pour construire les URL */
	protected $router;

	/** Titre de la page, rempli par une des méthodes make???Page() */
	protected $title;
	/** Contenu principal de la page, rempli par une des méthodes make???Page()  */
	protected $content;

	public function __construct(Router $router) {
		$this->router = $router;
	}

	/**
	 * Affiche la page qui a été préparée auparavant.
	 */
	public function render() {
		/*
		 * Ici on pourrait faire des echo, mais simplement fermer
		 * la balise PHP revient au même, et le HTML est plus lisible.
		 * En revanche le code PHP est moins lisible : une autre solution
		 * est de mettre ce squelette dans un fichier à part et
		 * de simplement faire un «include» (c'est ce qui a été fait pour
		 * le site des poèmes).
		 */
?>
<!DOCTYPE html>
<html lang="fr">
<head>
	<title><?php echo $this->title; ?></title>
	<meta charset="UTF-8" />
</head>
<body>
	<main>
		<h1><?php echo $this->title; ?></h1>
<?php echo $this->content; ?>
	</main>
</body>
</html>
<?php /* fin de l'affichage de la page et fin de la méthode render() */
	}

	/**
	 * Une fonction pour échapper les caractères spéciaux de HTML.
	 * Encapsule celle de PHP, trop lourde à utiliser car
	 * nécessite trop d'options.
	 */
	public static function htmlesc($str) {
		return htmlspecialchars($str,
			ENT_QUOTES  /* on échappe guillemets _et_ apostrophes */
			| ENT_SUBSTITUTE  /* les séquences UTF-8 invalides sont
			                   * remplacées par le caractère �
			                   * (au lieu de renvoyer la chaîne vide…) */
			
			| ENT_HTML5,  /* on utilise les entités HTML5 (en particulier &apos;) */
			'UTF-8'  /* encodage de la chaîne passée en entrée */
		);
	}

	/**
	 * Remplit la vue avec un message d'erreur pour le cas
	 * où l'internaute a demandé un animal inconnu.
	 */
	public function makeUnknownAnimalPage() {
		$this->title = 'Erreur : animal inconnu';
		$this->content = 'L’animal que vous avez demandé n’existe pas.';
	}

	/**
	 * Remplit la vue avec du texte quelconque.
	 */
	public function makeTestPage() {
		$this->title = 'Hello World!';
		$this->content = 'Lorem ipsum dolor sit amet.';
	}

	/**
	 * Remplit la vue avec la page d'accueil.
	 */
	public function makeHomePage() {
		$this->title = 'Animaux';
		$this->content = 'Bienvenue sur ce site consacré aux animaux.';
	}

	/**
	 * Remplit la vue avec une liste de tous les animaux.
	 * @param $animals Un tableau associatif identifiant => instance de Animal
	 */
	public function makeListPage(array $animals) {
		/* On construit la liste dans une variable temporaire, pour
		 * que ce soit un peu plus lisible et rapide à écrire */
		$s = '';
		$s .= '<p>Voici la liste des animaux du site :</p>';
		$s .= "\n<ul>\n";
		foreach ($animals as $id => $a) {
			$s .= '<li><a href="'.$this->router->getAnimalURL($id).'">'.self::htmlesc($a->getName()).' ('.self::htmlesc($a->getSpecies()).")</a></li>\n";
		}
		$s .= "</ul>\n";

		$this->title = 'Liste des animaux';
		$this->content = $s;
	}

	/**
	 * Remplit la vue avec des informations sur un animal.
	 */
	public function makeAnimalPage($animal) {
		$this->title = 'Page sur '.self::htmlesc($animal->getName());
		$this->content = '<p>'.self::htmlesc($animal->getName()).' est un animal de l’espèce '
			.self::htmlesc($animal->getSpecies()).', âgé de '.self::htmlesc($animal->getAge()).' ans.</p>';
	}

}

?>
